from setuptools import setup


setup(
    name='CVrail',
    version='1.9.2',
    author='Simão Duarte',
    author_email='maravilha1sapo@hotmail.com',
    url='https://gitlab.com/simaoduarte/cvrail',
    description="Detecta a movimentação nos taludes ferroviários",
    long_description='Tirar fotos detetar diferenças'
)

